# ccsds Python bindings

[![Actions Status](https://img.shields.io/github/actions/workflow/status/bmflynn/ccsdspy/CI.yml?branch=main&logo=github&style=flat-square)](https://github.com/bmflynn/ccsdspy/actions)

`ccsdspy` provides Python bindnigs for the [ccsds](https://github.com/bmflynn/ccsds-rs)
Rust bindings using [pyo3](https://pyo3.rs).


## Related

* [spacecraftsdb](https://github.com/bmflynn/spacecraftsdb): JSON Spacecraft metadata database
* [spacecrafts-rs](https://github.com/bmflynn/spacecrafts-rs): Rust crate interfacing with `spacecraftsdb`
* [ccsds-rs](https://github.com/bmflynn/ccsds-rs): Rust crate for CCSDS spacecraft frame & spacepacket decoding
